@@ -6,7 +6,7 @@ try:
     # Django >= 1.4.5
     from django.utils.encoding import force_bytes, force_text, smart_text  # NOQA
     from django.utils.six import string_types, text_type  # NOQA
-except ImportError:
+except ImportError:  # pragma: no cover
     # Django < 1.4.5
     from django.utils.encoding import (                         # NOQA
         smart_unicode as smart_text, smart_str as force_bytes)  # NOQA
@@ -17,7 +17,7 @@ except ImportError:
 try:
     # Django >= 1.4
     from django.utils.crypto import get_random_string  # NOQA
-except ImportError:
+except ImportError:  # pragma: no cover
     # Django < 1.4
     from random import choice
     get_random_string = lambda n: ''.join(
