@@ -4,6 +4,7 @@ from __future__ import unicode_literals
 import os
 import re
 
+from django.core.exceptions import SuspiciousOperation
 from django.core.urlresolvers import reverse
 from django.http import HttpResponse
 from django.test import TestCase
@@ -40,6 +41,13 @@ class TestCSRFCryptMiddleware(TestCase):
         middleware.process_request(request)
         self.assertEqual(request.POST.get('csrfmiddlewaretoken'), 'abc123')
 
+    def test_tampering(self):
+        request = RequestFactory().post(
+            '/', {'csrfmiddlewaretoken': '123$abc'})
+        middleware = CSRFCryptMiddleware()
+        with self.assertRaises(SuspiciousOperation):
+            middleware.process_request(request)
+
 
 class TestRandomCommentMiddleware(TestCase):
 
@@ -94,6 +102,12 @@ class TestContextProcessor(TestCase):
         self.assertTrue(force_text(context['csrf_token']))
         self.assertNotEqual(force_text(context['csrf_token']), 'abc123')
 
+    def test_no_token_csrf(self):
+        request = RequestFactory().get('/')
+        context = csrf(request)
+        self.assertTrue(force_text(context['csrf_token']))
+        self.assertEqual(force_text(context['csrf_token']), 'NOTPROVIDED')
+
 
 @skipUnless(
     'test_project' in os.environ.get('DJANGO_SETTINGS_MODULE', ''),
